@@ -16,7 +16,7 @@
 #define GTKMM_MINOR_VERSION 24
 
 /* Micro version number of gtkmm. */
-#define GTKMM_MICRO_VERSION 4
+#define GTKMM_MICRO_VERSION 8
 
 /* Define when building gtkmm as a static library. */
 /* #undef GTKMM_STATIC_LIB */
@@ -30,8 +30,10 @@
 #ifdef GTKMM_DLL
 # if defined(GTKMM_BUILD)
 #  define GTKMM_API __declspec(dllexport)
-# else
+# elif !defined (__GNUC__)
 #  define GTKMM_API __declspec(dllimport)
+# else /* don't dllimport classes/methods on GCC/MinGW */
+#  define GTKMM_API
 # endif
 #else
 /* Build a static library or a non-native Windows library or gendef is used. */
